#! /usr/bin/env python
# Copyright (C) 2009, 2010 Canonical Ltd

import time
import feedparser

STABLE_VERSION = "2.3.4"
TEST_VERSION = "2.4b5"


PROJECTS = [
    dict(href="http://www.gnu.org/", title="GNU", img="../bzricons/gnu.png"),
    dict(href="http://www.linuxfoundation.org/", title="Linux Foundation",
        img="../bzricons/linux-foundation-48x48.png"),
    dict(href="http://www.ubuntu.com/", title="Ubuntu",
        img="../bzricons/ubuntu_black-orange_hex_su.png"),
    dict(href="http://www.mysql.com/", title="MySQL",
        img="../bzricons/mysql.png"),
    dict(href="http://www.bugzilla.org/", title="Bugzilla",
        img="../bzricons/bugzilla.png"),
    dict(href="http://www.list.org/",
        title="GNU Mailman",
        img="../bzricons/mailman-logo2010-64x64.png"),
    dict(href="http://www.debian.org",
        title="Debian",
        img="../bzricons/debian-logo-50x61.png"),
    dict(href="http://www.askmonty.org/", title="MariaDB",
        img="../bzricons/maria-capt-64.png"),
    dict(href="http://www.drizzle.org/", title="Drizzle",
        img="../bzricons/drizzle64.png"),
    dict(href="http://www.inkscape.org/", title="Inkscape",
        img="../bzricons/inkscape.logo.png"),
    dict(href="https://launchpad.net/gwibber", title="Gwibber",
        img="../bzricons/gwibber.64x64.png"),
    dict(href="http://www.squid-cache.org/", title="Squid Cache",
        img="../bzricons/SquidPackage-logo.png"),
    dict(href="http://launchpad.net/", 
        title="Launchpad",
        img="../bzricons/launchpad-logo.png"),
    dict(href="http://do.davebsd.com/", title="GNOME Do",
        img="../bzricons/do.png"),
    dict(href="http://www.bitlbee.org/", title="BitlBee",
        img="../bzricons/bitlbee.png"),
    # some interesting projects to highlight over time ...
    #dict(href="http://sahana.lk/", title="Sahana",
    #   img="../bzricons/sahana6464.png"),
    #dict(href="http://gdesklets.de/", title="gDesklets",
    #   img="../bzricons/gdesklets.png"),
    #dict(href="https://launchpad.net/entertainer/", title="Entertainer",
    #   img="../bzricons/entertainer.png"),
    #dict(href="http://www.netrek.org/", title="Netrek",
    #   img="../bzricons/netrek.png"),
    #dict(href="http://www.moovida.com/", title="Moovida",
    #   img="../bzricons/moovida.png"),
    ]


def build_feed(title, rss_url, count):
    print "fetching data from %s" % (rss_url,)
    # we use our own copy of feedparser with a patch to let
    # <http://code.google.com/p/feedparser/issues/detail?id=224> extra_headers
    # be passed
    d = feedparser.parse(rss_url, extra_headers={'Cache-control': 'max-age=60'})
    entries = []
    for entry in d.entries[0:count]:
        entries.append(dict(
            title = entry.title,
            url = entry.link,
            date = time.strftime("%d-%b-%Y", entry.date_parsed),
            ))
    url = d.feed.link
    return dict(title=title, rss=rss_url, url=url, entries=entries)


def jinja_compile(context):
    """Compile the templates using the context given.

    :param context: dictionary of context objects
    """
    # TODO: generalise so that all files (not starting with underscore)
    # found under a templates directory are compiled.
    from jinja2 import Environment, FileSystemLoader
    def save(content, filename):
        f = open(filename, 'wb')
        try:
            f.write(content.encode('utf-8'))
        finally:
            f.close()
    loader = FileSystemLoader("templates/en")
    env = Environment(loader=loader)
    pages = ['index']
    for page in pages:
        path = "%s.html" % page
        template = env.get_template(path)
        result = template.render(context)
        save(result, "en/%s" % path)


# URLs of RSS feeds
NEWS_RSS = "http://feeds.launchpad.net/bazaar/announcements.atom"
CORE_RSS = "http://feeds.launchpad.net/bzr/announcements.atom"
BLOG_RSS = "http://bazaarvcs.wordpress.com/feed/"


def main():
    feeds = [
        build_feed("Community News", NEWS_RSS, 4),
        build_feed("Core News", CORE_RSS, 2),
        build_feed("Developer's Blog", BLOG_RSS, 3),
        ]
    context = {
        'feeds': feeds,
        'stable_version': STABLE_VERSION,
        'test_version': TEST_VERSION,
        'projects': PROJECTS,
        }
    jinja_compile(context)


if __name__ == "__main__":
    main()
